@@ -13,6 +13,8 @@
 
 #include "jdlib/miscutil.h"
 #include "jdlib/jdregex.h"
+#include "jdlib/miscmsg.h"
+#include "jdlib/timeout.h"
 
 #include "skeleton/view.h"
 #include "skeleton/dragnote.h"
@@ -59,13 +61,13 @@ ArticleAdmin::ArticleAdmin( const std::string& url )
     get_notebook()->set_fixtab( false );
     if( ! SESSION::get_show_article_tab() ) get_notebook()->set_show_tabs( false );
 
-    setup_menu( true );
+    setup_menu();
 
     // スムーススクロール用タイマセット
     // オートスクロール時など、スムースにスクロールをするため描画用タイマーを
     // メインタイマと別にする。DrawAreaBase::clock_in_smooth_scroll() も参照すること
     sigc::slot< bool > slot_timeout = sigc::bind( sigc::mem_fun(*this, &ArticleAdmin::clock_in_smooth_scroll ), 0 );
-    sigc::connection conn = Glib::signal_timeout().connect( slot_timeout, TIMER_TIMEOUT_SMOOTH_SCROLL );
+    JDLIB::Timeout::connect( slot_timeout, TIMER_TIMEOUT_SMOOTH_SCROLL );
 }
 
 
@@ -107,11 +109,11 @@ void ArticleAdmin::restore( const bool only_locked )
     const bool online = SESSION::is_online();
     SESSION::set_online( false );
 
-    std::list< std::string >& list_url = SESSION::get_article_URLs();
-    std::list< std::string >::iterator it_url = list_url.begin();
+    const std::list< std::string >& list_url = SESSION::get_article_URLs();
+    std::list< std::string >::const_iterator it_url = list_url.begin();
 
-    std::list< bool > list_locked = SESSION::get_article_locked();
-    std::list< bool >::iterator it_locked = list_locked.begin();
+    const std::list< bool >& list_locked = SESSION::get_article_locked();
+    std::list< bool >::const_iterator it_locked = list_locked.begin();
 
     for( int page = 0; it_url != list_url.end(); ++it_url, ++page ){
 
@@ -125,6 +127,12 @@ void ArticleAdmin::restore( const bool only_locked )
         // ロックされているものだけ表示
         if( only_locked && ! lock ) continue;
 
+        // 板がDBに登録されていない場合は表示しない
+        if( DBTREE::url_boardbase( *it_url ).empty() ){
+            MISC::ERRMSG(  *it_url + " is not registered" );
+            continue;
+        }
+
         if( page == SESSION::article_page() ) set_page_num = get_tab_nums();
 
         // 検索ビューなど、復元したときに view のurlが変わることがあるので
@@ -345,12 +353,20 @@ COMMAND_ARGS ArticleAdmin::get_open_list_args( const std::string& url, const COM
     COMMAND_ARGS command_arg;
     command_arg.arg4 = "MAIN";
 
-    CORE::core_set_command( "set_history_article", url );
-
     return command_arg;
 }
 
 
+//
+// カレントビューでポップアップ表示していたら隠す(インスタンスは削除しない)
+//
+void ArticleAdmin::hide_popup()
+{
+    SKELETON::View* view = get_current_view();
+    if( view ) view->set_command( "hide_popup" );
+}
+
+
 //
 // カレントビューでポップアップ表示していたら消す
 //
@@ -516,9 +532,9 @@ void ArticleAdmin::show_toolbar()
         get_notebook()->append_toolbar( *m_search_toolbar );
 
         if( SESSION::get_show_article_toolbar() ){
-            m_toolbar->show_toolbar();
-            m_toolbarsimple->show_toolbar();
-            m_search_toolbar->show_toolbar();
+            m_toolbar->open_buttonbar();
+            m_toolbarsimple->open_buttonbar();
+            m_search_toolbar->open_buttonbar();
         }
     }
 
@@ -527,21 +543,38 @@ void ArticleAdmin::show_toolbar()
 
 
 //
-// ツールバー表示切り替え
+// ツールバー表示/非表示切り替え
 //
 void ArticleAdmin::toggle_toolbar()
 {
     if( ! m_toolbar ) return;
 
     if( SESSION::get_show_article_toolbar() ){
-        m_toolbar->show_toolbar();
-        m_toolbarsimple->show_toolbar();
-        m_search_toolbar->show_toolbar();
+
+        m_toolbar->open_buttonbar();
+        m_toolbarsimple->open_buttonbar();
+        m_search_toolbar->open_buttonbar();
+
+        switch( get_notebook()->get_current_toolbar() ){
+
+            case TOOLBAR_ARTICLE:
+                m_toolbar->show_toolbar();
+                break;
+
+            case TOOLBAR_SIMPLE:
+                m_toolbarsimple->show_toolbar();
+                break;
+
+            case TOOLBAR_SEARCH:
+                m_search_toolbar->show_toolbar();
+                break;
+        }
+
     }
     else{
-        m_toolbar->hide_toolbar();
-        m_toolbarsimple->hide_toolbar();
-        m_search_toolbar->hide_toolbar();
+        m_toolbar->close_buttonbar();
+        m_toolbarsimple->close_buttonbar();
+        m_search_toolbar->close_buttonbar();
     }
 }
 
@@ -551,20 +584,31 @@ void ArticleAdmin::toggle_toolbar()
 //
 void ArticleAdmin::open_searchbar()
 {
+    if( ! m_toolbar ) return;
+
     SKELETON::View* view = get_current_view();
     if( ! view ) return;
 
-    if( m_toolbar ){
-        m_toolbar->open_searchbar();
-        if( view->get_id_toolbar() == TOOLBAR_ARTICLE ) m_toolbar->focus_entry_search();
-    }
-    if( m_toolbarsimple ){
-        m_toolbarsimple->open_searchbar();
-        if( view->get_id_toolbar() == TOOLBAR_SIMPLE ) m_toolbarsimple->focus_entry_search();
-    }
-    if( m_search_toolbar ){
-        m_search_toolbar->open_searchbar();
-        if( view->get_id_toolbar() == TOOLBAR_SEARCH ) m_search_toolbar->focus_entry_search();
+    m_toolbar->open_searchbar();
+    m_toolbarsimple->open_searchbar();
+    m_search_toolbar->open_searchbar();
+
+    switch( get_notebook()->get_current_toolbar() ){
+
+        case TOOLBAR_ARTICLE:
+            m_toolbar->show_toolbar();
+            m_toolbar->focus_entry_search();
+            break;
+
+        case TOOLBAR_SIMPLE:
+            m_toolbarsimple->show_toolbar();
+            m_toolbarsimple->focus_entry_search();
+            break;
+
+        case TOOLBAR_SEARCH:
+            m_search_toolbar->show_toolbar();
+            m_search_toolbar->focus_entry_search();
+            break;
     }
 }
 
@@ -574,9 +618,11 @@ void ArticleAdmin::open_searchbar()
 //
 void ArticleAdmin::close_searchbar()
 {
-    if( m_toolbar ) m_toolbar->close_searchbar();
-    if( m_toolbarsimple ) m_toolbarsimple->close_searchbar();
-    if( m_search_toolbar ) m_search_toolbar->close_searchbar();
+    if( ! m_toolbar ) return;
+
+    m_toolbar->close_searchbar();
+    m_toolbarsimple->close_searchbar();
+    m_search_toolbar->close_searchbar();
 }
 
 
@@ -590,8 +636,13 @@ void ArticleAdmin::command_local( const COMMAND_ARGS& command )
         if( view ) view->set_command( "goto_num", command.arg1 );
     }
 
-    // ポップアップ消去
+    // ポップアップを隠す(インスタンスは削除しない)
+    else if( command.command == "hide_popup" ) hide_popup();
+
+    // ポップアップを消去
     else if( command.command == "delete_popup" ) delete_popup();
+
+    // 全ポップアップを消去
     else if( command.command == "delete_all_popups" ) delete_all_popups();
 
     // ポップアップメニューの再作成
