@@ -89,6 +89,10 @@ void CONFIG::set_color( const int id, const std::string& color )
 void CONFIG::reset_colors(){ get_confitem()->reset_colors(); }
 
 const bool CONFIG::get_use_tree_gtkrc(){ return get_confitem()->use_tree_gtkrc; }
+void CONFIG::set_use_tree_gtkrc( const bool use ){ get_confitem()->use_tree_gtkrc = use; }
+
+const bool CONFIG::get_use_select_gtkrc(){ return get_confitem()->use_select_gtkrc; }
+void CONFIG::set_use_select_gtkrc( const bool use ){ get_confitem()->use_select_gtkrc = use; }
 
 const int CONFIG::get_tree_ypad(){ return get_confitem()->tree_ypad; }
 
@@ -215,6 +219,7 @@ const int CONFIG::get_del_imgabone_day(){ return get_confitem()->del_imgabone_da
 void CONFIG::set_del_imgabone_day( const int day ){ get_confitem()->del_imgabone_day = day; }
 const int CONFIG::get_max_img_size(){ return get_confitem()->max_img_size; }
 const int CONFIG::get_max_img_pixel(){ return get_confitem()->max_img_pixel; }
+const int CONFIG::get_imgcache_size(){ return get_confitem()->imgcache_size; }
 
 const bool CONFIG::get_show_oldarticle(){ return get_confitem()->show_oldarticle; }
 void CONFIG::set_show_oldarticle( const bool showarticle ){ get_confitem()->show_oldarticle = showarticle; }
@@ -416,6 +421,9 @@ const bool CONFIG::get_bookmark_drop(){ return get_confitem()->bookmark_drop; }
 // お気に入りの更新チェック時に板の更新もチェックする
 const bool CONFIG::get_check_update_board(){ return get_confitem()->check_update_board; }
 
+// 起動時にお気に入りを自動でチェックする
+const bool CONFIG::get_check_update_boot(){ return get_confitem()->check_update_boot; }
+
 // Ctrl+qでウィンドウを閉じない
 const bool CONFIG::get_disable_close(){ return get_confitem()->disable_close; }
 
