@@ -161,6 +161,15 @@ const bool DBTREE::move_board( const std::string& url_old, const std::string& ur
     return get_root()->move_board( url_old, url_new, false );
 }
 
+void DBTREE::set_enable_save_movetable( const bool set )
+{
+    get_root()->set_enable_save_movetable( set );
+}
+
+void DBTREE::save_movetable()
+{
+    get_root()->save_movetable();
+}
 
 const XML::Document& DBTREE::get_xml_document()
 {
@@ -531,14 +540,15 @@ void DBTREE::read_boardinfo_all()
     DBTREE::get_root()->read_boardinfo_all();
 }
 
-std::list< std::string > DBTREE::search_cache_all( const std::string& url, const std::string& query, bool mode_or, bool& stop )
+void DBTREE::search_cache_all( std::list< DBTREE::ArticleBase* >& list_article,
+                               const std::string& query, const bool mode_or, const bool& stop )
 {
-    return DBTREE::get_root()->search_cache( query, mode_or, stop );
+    DBTREE::get_root()->search_cache( list_article, query, mode_or, stop );
 }
 
-std::list< std::string > DBTREE::search_cache( const std::string& url, const std::string& query, bool mode_or, bool& stop )
+void DBTREE::search_cache( const std::string& url, std::list< DBTREE::ArticleBase* >& list_article, const std::string& query, const bool mode_or, const bool& stop )
 {
-    return DBTREE::get_board( url )->search_cache( query, mode_or, stop );
+    DBTREE::get_board( url )->search_cache( list_article, query, mode_or, stop );
 }
 
 void DBTREE::board_update_writetime( const std::string& url )
@@ -848,6 +858,11 @@ const bool DBTREE::article_is_loading( const std::string& url )
     return DBTREE::get_article( url )->is_loading();
 }
 
+const bool DBTREE::article_is_checking_update( const std::string& url )
+{
+    return DBTREE::get_article( url )->is_checking_update();
+}
+
 void DBTREE::article_download_dat( const std::string& url, const bool check_update )
 {
     DBTREE::get_article( url )->download_dat( check_update );
