@@ -52,6 +52,9 @@ ImageAdmin::ImageAdmin( const std::string& url )
     m_left.set_label( "<" );
     m_right.set_label( ">" );
 
+    m_left.set_focus_on_click( false );
+    m_right.set_focus_on_click( false );
+
     m_left.signal_pressed().connect( sigc::mem_fun( *this, &ImageAdmin::slot_press_left ) );
     m_right.signal_pressed().connect( sigc::mem_fun( *this, &ImageAdmin::slot_press_right ) );
     m_left.signal_released().connect( sigc::mem_fun( *this, &ImageAdmin::slot_release_left ) );
@@ -326,7 +329,7 @@ void ImageAdmin::open_view( const COMMAND_ARGS& command )
 //
 // タブの切替え
 //
-void ImageAdmin::tab_left()
+void ImageAdmin::tab_left( const bool updated )
 {
     if( m_iconbox.children().size() == 1 ) return;
 
@@ -354,7 +357,7 @@ void ImageAdmin::tab_left()
 }
 
 
-void ImageAdmin::tab_right()
+void ImageAdmin::tab_right( const bool updated )
 {
     if( m_iconbox.children().size() == 1 ) return;
 
@@ -953,7 +956,7 @@ void ImageAdmin::save_all()
     std::cout << "ImageAdmin::save_all\n";
 #endif
 
-    int overwrite = 0; // -1 なら全てNO、1ならすべてYES
+    int overwrite = Gtk::RESPONSE_NO;
 
     std::list< std::string > list_urls = get_URLs();
 
@@ -966,7 +969,7 @@ void ImageAdmin::save_all()
 
         diag.hide();
 
-        std::string path_dir = diag.get_filename();
+        std::string path_dir = MISC::recover_path( diag.get_filename() );
         if( path_dir.empty() ) return;
         if( path_dir.c_str()[ path_dir.length()-1 ] != '/' ) path_dir += "/";
         
@@ -996,10 +999,14 @@ void ImageAdmin::save_all()
                 if( CACHE::file_exists( path_to ) == CACHE::EXIST_FILE ){
 
                     // すべて上書き
-                    if( overwrite == 1 ){
+                    if( overwrite == SKELETON::OVERWRITE_YES_ALL ){
                         if( ! copy_file( url, path_from, path_to ) ) return;
                     }
-                    else if( overwrite != -1 ){
+
+                    // すべていいえ
+                    else if( overwrite == SKELETON::OVERWRITE_NO_ALL ){}
+
+                    else{
 
                         // ビューを切り替えてURLやステータス更新
                         switch_img( url );
@@ -1008,24 +1015,19 @@ void ImageAdmin::save_all()
 
                         for(;;){
 
-                            SKELETON::MsgDiag mdiag( get_win(), "ファイルが存在します。ファイル名を変更して保存しますか？", 
-                                                     false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_NONE );
-                            mdiag.add_button( Gtk::Stock::NO, Gtk::RESPONSE_NO );
-                            mdiag.add_button( Gtk::Stock::YES, Gtk::RESPONSE_YES );
-                            mdiag.add_button( "上書き", Gtk::RESPONSE_YES + 100 );
-                            mdiag.add_button( "すべていいえ", Gtk::RESPONSE_NO + 200 );
-                            mdiag.add_button( "すべて上書き", Gtk::RESPONSE_YES + 200 );
+                            SKELETON::MsgOverwriteDiag mdiag( get_win() );
 
-                            int ret = mdiag.run();
+                            overwrite = mdiag.run();
                             mdiag.hide();
 
-                            switch( ret ){
+                            switch( overwrite ){
 
                                 // すべて上書き
-                                case Gtk::RESPONSE_YES + 200:
-                                    overwrite = 1;
+                                case SKELETON::OVERWRITE_YES_ALL:
+
                                     // 上書き
-                                case Gtk::RESPONSE_YES + 100:
+                                case SKELETON::OVERWRITE_YES:
+
                                     if( ! copy_file( url, path_from, path_to ) ) return;
                                     break;
 
@@ -1034,11 +1036,6 @@ void ImageAdmin::save_all()
                                     if( ! DBIMG::save( url, get_win(), path_to ) ) continue;
                                     break;
 
-                                    //  すべていいえ
-                                case Gtk::RESPONSE_NO + 200:
-                                    overwrite = -1;
-                                    break;
-
                                 default:
                                     break;
                             }
@@ -1053,7 +1050,11 @@ void ImageAdmin::save_all()
             }
 
         }
-        else MISC::ERRMSG( "can't create " + path_dir );
+        else{
+
+            SKELETON::MsgDiag mdiag( get_win(), path_dir + "\n\nの作成に失敗しました。\nハードディスクの容量やパーミッションなどを確認してください。\n\n画像保存をキャンセルしました。原因を解決してからもう一度保存を行ってください。" );
+            mdiag.run();
+        }
     }
 }
 
