@@ -100,8 +100,8 @@ void restore_bkup()
             delete mdiag;
         }
         else{
-            if( bkup_main ) unlink( path_main_bkup.c_str() );
-            if( bkup_favor ) unlink( path_favor_bkup.c_str() );
+            if( bkup_main ) unlink( to_locale_cstr( path_main_bkup ) );
+            if( bkup_favor ) unlink( to_locale_cstr( path_favor_bkup ) );
         }
     }
 }
@@ -309,6 +309,8 @@ void usage( const int status )
     "        Does not terminate even if it is a subprocess\n"
     "-s, --skip-setup\n"
     "        Skip the setup dialog\n"
+    "-l, --logfile\n"
+    "        Write message to msglog file\n"
     "-V, --version\n"
     "        Display version of this program\n";
 
@@ -342,13 +344,14 @@ int main( int argc, char **argv )
 
     // "現在のタブ/新規タブ"など引数によって開き方を変えたい場合は、--tab=<url>
     // など新しいオプションを追加する
-    // --help, --tab=<url>, --multi, --version
+    // --help, --tab=<url>, --multi, --logfile --version
     const struct option options[] =
     {
         { "help", 0, 0, 'h' },
         //{ "tab", 1, 0, 't' },
         { "multi", 0, 0, 'm' },
         { "skip-setup", 0, 0, 's' },
+        { "logfile", 0, 0, 'l' },
         { "version", 0, 0, 'V' },
         { 0, 0, 0, 0 }
     };
@@ -356,10 +359,11 @@ int main( int argc, char **argv )
     std::string url;
     bool multi_mode = false;
     bool skip_setupdiag = false;
+    bool logfile_mode = false;
 
-    // -h, -t <url>, -m, -V
+    // -h, -t <url>, -m, -s, -l, -V
     int opt = 0;
-    while( ( opt = getopt_long( argc, argv, "ht:msV", options, NULL ) ) != -1 )
+    while( ( opt = getopt_long( argc, argv, "ht:mslV", options, NULL ) ) != -1 )
     {
         switch( opt )
         {
@@ -379,6 +383,10 @@ int main( int argc, char **argv )
                 skip_setupdiag = true;
                 break;
 
+            case 'l': // メッセージをログファイルに出力
+                logfile_mode = true;
+                break;
+
             case 'V': // バージョンと完全なconfigureオプションを表示
                 std::cout << "JD " << ENVIRONMENT::get_jdversion() << ", " <<
                 ENVIRONMENT::get_jdcopyright() << "\n"
@@ -398,7 +406,7 @@ int main( int argc, char **argv )
             url = argv[ optind ];
         }
         // -m 、-s でなく、URLを含まない引数だけの場合は終了
-        else if( optind > 1 && ! ( multi_mode || skip_setupdiag ) ) return 0;
+        else if( optind > 1 && ! ( multi_mode || skip_setupdiag || logfile_mode ) ) return 0;
     }
     /*---------------------------------------------------------------*/
 
@@ -493,6 +501,12 @@ int main( int argc, char **argv )
         CACHE::mkdir_root();
     }
 
+    // メッセージをログファイルに出力
+    if( logfile_mode && CACHE::mkdir_logroot() ){
+        freopen( to_locale_cstr( CACHE::path_msglog() ), "ab", stdout );
+        freopen( to_locale_cstr( CACHE::path_msglog() ), "ab", stderr );
+    }
+
     /*--- IOMonitor -------------------------------------------------*/
 #ifndef _WIN32
     CORE::IOMonitor iomonitor;
