@@ -17,7 +17,7 @@ namespace CORE
     enum
     {
         PREFDIAG_PASSWD,
-        PREFDIAG_PRIVARY,
+        PREFDIAG_PRIVACY,
         PREFDIAG_BROWSER,
         PREFDIAG_LINKFILTER,
         PREFDIAG_USRCMD,
@@ -30,8 +30,9 @@ namespace CORE
         PREFDIAG_MAINITEM,
         PREFDIAG_SIDEBARITEM,
         PREFDIAG_BOARDITEM,
-        PREFDIAG_BOARDITEMCOLUM,
+        PREFDIAG_BOARDITEM_COLUM,
         PREFDIAG_ARTICLEITEM,
+        PREFDIAG_ARTICLEITEM_MENU,
         PREFDIAG_MSGITEM,
 
         PREFDIAG_DELIMG,
