@@ -1,7 +1,12 @@
 // ライセンス: GPL2
 //
 // タブをドラッグしてページを入れ替え可能なNoteBook
-
+//
+// DragableNoteBook は 下の3つの notebook から構成されている
+//
+// タブ : TabNotebook
+// ツールバー : ToolBarNotebook
+// ビュー : ViewNotebook
 
 #ifndef _DRAGNOTE_H
 #define _DRAGNOTE_H
@@ -9,6 +14,7 @@
 #include "tabnote.h"
 #include "toolbarnote.h"
 #include "viewnote.h"
+#include "tabswitchbutton.h"
 
 #include "tooltip.h"
 
@@ -24,53 +30,62 @@ namespace SKELETON
     class IconPopup;
 
     typedef sigc::signal< void, GtkNotebookPage*, int > SIG_SWITCH_PAGE;
-    typedef sigc::signal< void, int > SIG_TAB_CLICK;
+    typedef sigc::signal< void, int > SIG_TAB_CLICKED;
     typedef sigc::signal< void, int > SIG_TAB_CLOSE;
     typedef sigc::signal< void, int > SIG_TAB_RELOAD;
     typedef sigc::signal< void, int, int , int > SIG_TAB_MENU;
+    typedef sigc::signal< void, GdkEventScroll* > SIG_TAB_SCROLLED;
 
-    // D&D
-    typedef sigc::signal< void, int > SIG_DRAG_BEGIN;
-    typedef sigc::signal< void > SIG_DRAG_END;
+    typedef sigc::signal< void, Gtk::SelectionData&, const int > SIG_DRAG_DATA_GET;
 
     // DragableNoteBook を構成している各Notebookの高さ
     // 及びタブの高さや位置の情報
     struct Alloc_NoteBook
     {
+        int x_tab;
+        int height_tab;
+        int width_tab;
+
         int y_tabbar;
         int height_tabbar;
 
         int y_toolbar;
         int height_toolbar;
 
-        int height_view;
-
-        int x_tab;
-        int height_tab;
-        int width_tab;
+        int x_box;
+        int y_box;
+        int width_box;
+        int height_box;
     };
 
     class DragableNoteBook : public Gtk::VBox
     {
         SIG_SWITCH_PAGE m_sig_switch_page;
-        SIG_TAB_CLICK m_sig_tab_click;
+        SIG_TAB_CLICKED m_sig_tab_clicked;
         SIG_TAB_CLOSE m_sig_tab_close;
         SIG_TAB_RELOAD m_sig_tab_reload;
         SIG_TAB_MENU  m_sig_tab_menu;
+        SIG_TAB_SCROLLED m_sig_tab_scrolled;
 
-        SIG_DRAG_BEGIN m_sig_drag_begin;
-        SIG_DRAG_END m_sig_drag_end;
+        SIG_DRAG_DATA_GET m_sig_drag_data_get;
 
         // DragableNoteBook は 下の3つのノートブックから出来ている
         TabNotebook m_notebook_tab;  // タブ
         ToolBarNotebook m_notebook_toolbar; // ツールバー
         ViewNotebook m_notebook_view; // ビュー
 
+        Gtk::HBox m_hbox_tab;
+        TabSwitchButton m_bt_tabswitch; // タブの切り替えボタン
+        Gtk::Tooltips m_tooltip_tabswitch;
+
         bool m_show_tabs;
         bool m_show_toolbar;
 
         int m_page;
-        bool m_drag;
+
+        // タブをドラッグ中
+        bool m_dragging_tab;
+
         bool m_dblclick;
 
         // 入力コントローラ
@@ -85,13 +100,13 @@ namespace SKELETON
       public:
 
         SIG_SWITCH_PAGE signal_switch_page(){ return m_sig_switch_page; }
-        SIG_TAB_CLICK sig_tab_click() { return m_sig_tab_click; }
+        SIG_TAB_CLICKED sig_tab_clicked() { return m_sig_tab_clicked; }
         SIG_TAB_CLOSE sig_tab_close() { return m_sig_tab_close; }
         SIG_TAB_RELOAD sig_tab_reload(){ return m_sig_tab_reload; }
         SIG_TAB_MENU sig_tab_menu() { return m_sig_tab_menu; }
+        SIG_TAB_SCROLLED sig_tab_scrolled(){ return m_sig_tab_scrolled; }
 
-        SIG_DRAG_BEGIN sig_drag_begin() { return m_sig_drag_begin; }
-        SIG_DRAG_END sig_drag_end() { return m_sig_drag_end; }
+        SIG_DRAG_DATA_GET sig_drag_data_get() { return m_sig_drag_data_get; }
 
         DragableNoteBook();
         virtual ~DragableNoteBook();
@@ -99,9 +114,8 @@ namespace SKELETON
         void clock_in();
         void focus_out();
 
-        // DragableNoteBook を構成している各Notebookの高さ
-        // 及びタブの高さと位置を取得 ( 枠の描画用 )
-        const Alloc_NoteBook get_alloc_notebook();
+        // 枠描画
+        void draw_box( Gtk::Widget* widget, GdkEventExpose* event );
 
         const bool get_show_tabs() const{ return m_show_tabs; }
         void set_show_tabs( bool show_tabs );
@@ -117,6 +131,7 @@ namespace SKELETON
         void remove_page( int page );
 
         // ツールバー関係
+        // 各Adminクラスの virtual void show_toolbar()でツールバーを作成してappend_toolbar()で登録する
         void show_toolbar();
         void hide_toolbar();
         void append_toolbar( Gtk::Widget& toolbar );
@@ -127,10 +142,11 @@ namespace SKELETON
         void update_toolbar_button();
 
         // タブの文字列取得/セット
-        const std::string get_tab_fulltext( int page );
-        void set_tab_fulltext( const std::string& str, int page );
+        const std::string get_tab_fulltext( const int page );
+        void set_tab_fulltext( const std::string& str, const int page );
 
-        // タブにアイコンをセットする
+        // タブのアイコン取得/セット
+        const int get_tabicon( const int page );
         void set_tabicon( const std::string& iconname, const int page, const int icon );
 
         // ドラッグ可/不可切り替え(デフォルト false );
@@ -142,10 +158,17 @@ namespace SKELETON
         // タブ幅調整
         bool adjust_tabwidth();
 
+        // タブ切り替えボタン
+        Gtk::Button& get_tabswitch_button(){ return m_bt_tabswitch.get_button(); }
+
       private:
 
         virtual bool on_expose_event( GdkEventExpose* event );
 
+        // DragableNoteBook を構成している各Notebookの高さ
+        // 及びタブの高さと位置を取得 ( 枠の描画用 )
+        const Alloc_NoteBook get_alloc_notebook();
+
         // ツールバー取得
         SKELETON::ToolBar* get_toolbar( int page );
 
@@ -159,6 +182,9 @@ namespace SKELETON
         bool slot_button_press_event( GdkEventButton* event );
         bool slot_button_release_event( GdkEventButton* event );
 
+        // notebook_tab の上でホイールを回した
+        bool slot_scroll_event( GdkEventScroll* event );
+
       protected:
 
         // コントローラ
@@ -170,6 +196,7 @@ namespace SKELETON
 
         void slot_drag_begin();
         void slot_drag_motion( const int page, const int tab_x, const int tab_y, const int tab_width );
+        void slot_drag_data_get( Gtk::SelectionData& selection_data );
         void slot_drag_end();
     };
 }
